WKExtendedRuntimeSessionInvalidationReason

Struct WKExtendedRuntimeSessionInvalidationReason 

#[repr(transparent)]
pub struct WKExtendedRuntimeSessionInvalidationReason(pub NSInteger);
Available on crate feature WKExtendedRuntimeSession only.
Defines the reasons for which a session may become invalid.

See also Apple’s documentation

Tuple Fields

0: NSInteger

Implementations

Source

impl WKExtendedRuntimeSessionInvalidationReason

pub const None: Self

The session ended normally, likely through a direct call to invalidate.

pub const SessionInProgress: Self

A session for this application has already been started, and is currently running, another session can not be started.

pub const Expired: Self

The session hit its time limit, as noted by its expiration date.

pub const ResignedFrontmost: Self

The application has lost frontmost status, so the session ended. Examples of actions by the user which cause the session to lose frontmost status include: User pressing digital crown, tapping on a notification to go to another application, switching applications through the dock, or any other apps entering the foreground.

pub const SuppressedBySystem: Self

Apple Watch is in a state that doesn’t currently allow this session type to run.

pub const Error: Self

The session did not end normally, and there is an error returned with more information.