pub struct WKInterfaceGroup { /* private fields */ }WKInterfaceGroup and WKInterfaceObject only.Expand description
Implementations
Sourceimpl WKInterfaceGroup
impl WKInterfaceGroup
pub unsafe fn setCornerRadius(&self, corner_radius: CGFloat)
objc2-core-foundation only.pub unsafe fn setContentInset(&self, content_inset: UIEdgeInsets)
objc2-ui-kit only.pub unsafe fn setBackgroundColor(&self, color: Option<&UIColor>)
objc2-ui-kit only.pub unsafe fn setBackgroundImage(&self, image: Option<&UIImage>)
objc2-ui-kit only.pub unsafe fn setBackgroundImageData(&self, image_data: Option<&NSData>)
pub unsafe fn setBackgroundImageNamed(&self, image_name: Option<&NSString>)
Sourceimpl WKInterfaceGroup
Methods declared on superclass WKInterfaceObject.
impl WKInterfaceGroup
Methods declared on superclass WKInterfaceObject.
Methods from Deref<Target = WKInterfaceObject>
pub unsafe fn setHidden(&self, hidden: bool)
pub unsafe fn setAlpha(&self, alpha: CGFloat)
objc2-core-foundation only.pub unsafe fn setSemanticContentAttribute( &self, semantic_content_attribute: WKInterfaceSemanticContentAttribute, )
WKInterfaceDevice only.pub unsafe fn setHorizontalAlignment( &self, horizontal_alignment: WKInterfaceObjectHorizontalAlignment, )
pub unsafe fn setVerticalAlignment( &self, vertical_alignment: WKInterfaceObjectVerticalAlignment, )
pub unsafe fn setWidth(&self, width: CGFloat)
objc2-core-foundation only.pub unsafe fn setHeight(&self, height: CGFloat)
objc2-core-foundation only.pub unsafe fn setRelativeWidth_withAdjustment( &self, width: CGFloat, adjustment: CGFloat, )
objc2-core-foundation only.pub unsafe fn setRelativeHeight_withAdjustment( &self, height: CGFloat, adjustment: CGFloat, )
objc2-core-foundation only.pub unsafe fn sizeToFitWidth(&self)
pub unsafe fn sizeToFitHeight(&self)
pub unsafe fn interfaceProperty(&self) -> Retained<NSString>
pub unsafe fn setAccessibilityIdentifier( &self, accessibility_identifier: Option<&NSString>, )
pub unsafe fn setAccessibilityLabel( &self, accessibility_label: Option<&NSString>, )
pub unsafe fn setAccessibilityHint(&self, accessibility_hint: Option<&NSString>)
pub unsafe fn setAccessibilityValue( &self, accessibility_value: Option<&NSString>, )
pub unsafe fn setIsAccessibilityElement(&self, is_accessibility_element: bool)
pub unsafe fn setAccessibilityTraits( &self, accessibility_traits: UIAccessibilityTraits, )
objc2-ui-kit only.pub unsafe fn setAccessibilityImageRegions( &self, accessibility_image_regions: &NSArray<WKAccessibilityImageRegion>, )
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for WKInterfaceGroup
impl AsRef<AnyObject> for WKInterfaceGroup
Sourceimpl AsRef<NSObject> for WKInterfaceGroup
impl AsRef<NSObject> for WKInterfaceGroup
Sourceimpl AsRef<WKInterfaceGroup> for WKInterfaceGroup
impl AsRef<WKInterfaceGroup> for WKInterfaceGroup
Sourceimpl AsRef<WKInterfaceObject> for WKInterfaceGroup
impl AsRef<WKInterfaceObject> for WKInterfaceGroup
Sourcefn as_ref(&self) -> &WKInterfaceObject
fn as_ref(&self) -> &WKInterfaceObject
Sourceimpl Borrow<AnyObject> for WKInterfaceGroup
impl Borrow<AnyObject> for WKInterfaceGroup
Sourceimpl Borrow<NSObject> for WKInterfaceGroup
impl Borrow<NSObject> for WKInterfaceGroup
Sourceimpl Borrow<WKInterfaceObject> for WKInterfaceGroup
impl Borrow<WKInterfaceObject> for WKInterfaceGroup
Sourcefn borrow(&self) -> &WKInterfaceObject
fn borrow(&self) -> &WKInterfaceObject
Sourceimpl ClassType for WKInterfaceGroup
impl ClassType for WKInterfaceGroup
Sourceconst NAME: &'static str = "WKInterfaceGroup"
const NAME: &'static str = "WKInterfaceGroup"
Sourcetype Super = WKInterfaceObject
type Super = WKInterfaceObject
Sourcetype ThreadKind = <<WKInterfaceGroup as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<WKInterfaceGroup as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for WKInterfaceGroup
impl Debug for WKInterfaceGroup
Sourceimpl Deref for WKInterfaceGroup
impl Deref for WKInterfaceGroup
Sourceimpl Hash for WKInterfaceGroup
impl Hash for WKInterfaceGroup
Sourceimpl Message for WKInterfaceGroup
impl Message for WKInterfaceGroup
Sourceimpl NSObjectProtocol for WKInterfaceGroup
impl NSObjectProtocol for WKInterfaceGroup
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl PartialEq for WKInterfaceGroup
impl PartialEq for WKInterfaceGroup
Sourceimpl RefEncode for WKInterfaceGroup
impl RefEncode for WKInterfaceGroup
Sourceconst ENCODING_REF: Encoding = <WKInterfaceObject as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <WKInterfaceObject as ::objc2::RefEncode>::ENCODING_REF
Sourceimpl WKImageAnimatable for WKInterfaceGroup
impl WKImageAnimatable for WKInterfaceGroup
Sourceunsafe fn startAnimating(&self)
unsafe fn startAnimating(&self)
WKInterfaceImage only.Sourceunsafe fn startAnimatingWithImagesInRange_duration_repeatCount(
&self,
image_range: NSRange,
duration: NSTimeInterval,
repeat_count: NSInteger,
)
unsafe fn startAnimatingWithImagesInRange_duration_repeatCount( &self, image_range: NSRange, duration: NSTimeInterval, repeat_count: NSInteger, )
WKInterfaceImage only.Sourceunsafe fn stopAnimating(&self)
unsafe fn stopAnimating(&self)
WKInterfaceImage only.