WKInterfaceSCNScene

Struct WKInterfaceSCNScene 

pub struct WKInterfaceSCNScene { /* private fields */ }
Available on crate features WKInterfaceObject and WKInterfaceSCNScene only.
Implementations

Source

impl WKInterfaceSCNScene

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

👎Deprecated: Use SceneKit.SceneView instead.
pub unsafe fn scene(&self) -> Option<Retained<SCNScene>>

Available on crate feature objc2-scene-kit only.

Specifies the scene of the receiver

pub unsafe fn setScene(&self, scene: Option<&SCNScene>)

Available on crate feature objc2-scene-kit only.

Setter for scene.

pub unsafe fn snapshot(&self) -> Retained<UIImage>

Available on crate feature objc2-ui-kit only.

Draws the contents of the view and returns them as a new image object

This method is thread-safe and may be called at any time.

pub unsafe fn preferredFramesPerSecond(&self) -> NSInteger

The rate you want the view to redraw its contents.

When your application sets its preferred frame rate, the view chooses a frame rate as close to that as possible based on the capabilities of the screen the view is displayed on. The actual frame rate chosen is usually a factor of the maximum refresh rate of the screen to provide a consistent frame rate. For example, if the maximum refresh rate of the screen is 60 frames per second, that is also the highest frame rate the view sets as the actual frame rate. However, if you ask for a lower frame rate, it might choose 30, 20, 15 or some other factor to be the actual frame rate. Your application should choose a frame rate that it can consistently maintain. The default value is 0 which means the display link will fire at the native cadence of the display hardware.

pub unsafe fn setPreferredFramesPerSecond( &self, preferred_frames_per_second: NSInteger, )

pub unsafe fn antialiasingMode(&self) -> SCNAntialiasingMode

Available on crate feature objc2-scene-kit only.

Defaults to SCNAntialiasingModeNone.

pub unsafe fn setAntialiasingMode(&self, antialiasing_mode: SCNAntialiasingMode)

Available on crate feature objc2-scene-kit only.

Setter for antialiasingMode.

Source

impl WKInterfaceSCNScene

Methods declared on superclass NSObject.

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = WKInterfaceObject>

pub unsafe fn setHidden(&self, hidden: bool)

pub unsafe fn setAlpha(&self, alpha: CGFloat)

Available on crate feature objc2-core-foundation only.
pub unsafe fn setSemanticContentAttribute( &self, semantic_content_attribute: WKInterfaceSemanticContentAttribute, )

Available on crate feature WKInterfaceDevice only.
pub unsafe fn setHorizontalAlignment( &self, horizontal_alignment: WKInterfaceObjectHorizontalAlignment, )

pub unsafe fn setVerticalAlignment( &self, vertical_alignment: WKInterfaceObjectVerticalAlignment, )

pub unsafe fn setWidth(&self, width: CGFloat)

Available on crate feature objc2-core-foundation only.
pub unsafe fn setHeight(&self, height: CGFloat)

Available on crate feature objc2-core-foundation only.
pub unsafe fn setRelativeWidth_withAdjustment( &self, width: CGFloat, adjustment: CGFloat, )

Available on crate feature objc2-core-foundation only.
pub unsafe fn setRelativeHeight_withAdjustment( &self, height: CGFloat, adjustment: CGFloat, )

Available on crate feature objc2-core-foundation only.
pub unsafe fn sizeToFitWidth(&self)

pub unsafe fn sizeToFitHeight(&self)

pub unsafe fn interfaceProperty(&self) -> Retained<NSString>

pub unsafe fn setAccessibilityIdentifier( &self, accessibility_identifier: Option<&NSString>, )

pub unsafe fn setAccessibilityLabel( &self, accessibility_label: Option<&NSString>, )

pub unsafe fn setAccessibilityHint(&self, accessibility_hint: Option<&NSString>)

pub unsafe fn setAccessibilityValue( &self, accessibility_value: Option<&NSString>, )

pub unsafe fn setIsAccessibilityElement(&self, is_accessibility_element: bool)

pub unsafe fn setAccessibilityTraits( &self, accessibility_traits: UIAccessibilityTraits, )

Available on crate feature objc2-ui-kit only.
pub unsafe fn setAccessibilityImageRegions( &self, accessibility_image_regions: &NSArray<WKAccessibilityImageRegion>, )

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}