WKExtendedRuntimeSessionDelegate

Trait WKExtendedRuntimeSessionDelegate 

pub unsafe trait WKExtendedRuntimeSessionDelegate: NSObjectProtocol {
    // Provided methods
    unsafe fn extendedRuntimeSession_didInvalidateWithReason_error(
        &self,
        extended_runtime_session: &WKExtendedRuntimeSession,
        reason: WKExtendedRuntimeSessionInvalidationReason,
        error: Option<&NSError>,
    )
       where Self: Sized + Message { ... }
    unsafe fn extendedRuntimeSessionDidStart(
        &self,
        extended_runtime_session: &WKExtendedRuntimeSession,
    )
       where Self: Sized + Message { ... }
    unsafe fn extendedRuntimeSessionWillExpire(
        &self,
        extended_runtime_session: &WKExtendedRuntimeSession,
    )
       where Self: Sized + Message { ... }
}
Available on crate feature WKExtendedRuntimeSession only.
Provided Methods

unsafe fn extendedRuntimeSession_didInvalidateWithReason_error( &self, extended_runtime_session: &WKExtendedRuntimeSession, reason: WKExtendedRuntimeSessionInvalidationReason, error: Option<&NSError>, )
where Self: Sized + Message,

Parameter extendedRuntimeSession: The session which has been invalidated

Parameter reason: The termination reason explaining why the session has been invalidated.

Parameter error: If reason is WKExtendedRuntimeSessionInvalidationReasonError, this object will represent that error.

This is called if a session fails to start, or when it ends once it has started. See WKExtendedRuntimeSeesionInvalidationReason for the reasons this may be called.

unsafe fn extendedRuntimeSessionDidStart( &self, extended_runtime_session: &WKExtendedRuntimeSession, )
where Self: Sized + Message,

Parameter extendedRuntimeSession: The session which started

Called when the session has started successfully.

unsafe fn extendedRuntimeSessionWillExpire( &self, extended_runtime_session: &WKExtendedRuntimeSession, )
where Self: Sized + Message,

Parameter extendedRuntimeSession: The session which is about to expire.

Delegate method provided to application to signify the session will expire soon. All tasks must be completed before the expiration date.