pub struct WKExtendedRuntimeSession { /* private fields */ }WKExtendedRuntimeSession only.Expand description
Implementations
Sourceimpl WKExtendedRuntimeSession
impl WKExtendedRuntimeSession
Sourcepub unsafe fn session() -> Retained<WKExtendedRuntimeSession>
pub unsafe fn session() -> Retained<WKExtendedRuntimeSession>
This method will create a session, with the capabilities granted for the appropriate session type specified in the “Background Modes” capability in Xcode.
Sourcepub unsafe fn requestAutoLaunchAuthorizationStatusWithCompletion(
completion: &DynBlock<dyn Fn(WKExtendedRuntimeSessionAutoLaunchAuthorizationStatus, *mut NSError)>,
)
Available on crate feature block2 only.
pub unsafe fn requestAutoLaunchAuthorizationStatusWithCompletion( completion: &DynBlock<dyn Fn(WKExtendedRuntimeSessionAutoLaunchAuthorizationStatus, *mut NSError)>, )
block2 only.Request auto-launch authorization for the current app. This may trigger prompt to the user asking if they want to make the current app the app to launch automatically when system conditions are met for the app’s supported session type. This prompt will only be shown to the user once per application. The completion handler will be called with an error if the application’s session type does not support auto-launch, or if the app is not foreground and has not yet triggered a prompt.
Sourcepub unsafe fn delegate(
&self,
) -> Option<Retained<ProtocolObject<dyn WKExtendedRuntimeSessionDelegate>>>
pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn WKExtendedRuntimeSessionDelegate>>>
Setting a delegate on the session provides you with updates on when the session begins, ends, or, encounters an error. Be sure to set a delegate before calling start, to receive the sessionDidStart callback.
Sourcepub unsafe fn setDelegate(
&self,
delegate: Option<&ProtocolObject<dyn WKExtendedRuntimeSessionDelegate>>,
)
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn WKExtendedRuntimeSessionDelegate>>, )
Setter for delegate.
This is a weak property.
Sourcepub unsafe fn state(&self) -> WKExtendedRuntimeSessionState
pub unsafe fn state(&self) -> WKExtendedRuntimeSessionState
The current state of the session.
Sourcepub unsafe fn expirationDate(&self) -> Option<Retained<NSDate>>
pub unsafe fn expirationDate(&self) -> Option<Retained<NSDate>>
The date at which the session will no longer receive runtime. Use this date to figure out how much time there is left to run before the end of the session. If the session has not yet started, this value will be nil. If the session successfully starts, this date will then be valid, even after the session gets invalidated.
Sourcepub unsafe fn startAtDate(&self, date: &NSDate)
pub unsafe fn startAtDate(&self, date: &NSDate)
Parameter date: A date in the future when the session should start running.
Use this method to schedule the session to run at future date. Calling this API must be done while the application is in the foreground, but the session will start at the appropriate date regardless of application state. This method can only be used for the alarm background mode.
Sourcepub unsafe fn invalidate(&self)
pub unsafe fn invalidate(&self)
This method will end a session early before its expiration date. If this method is called on a session scheduled through startAtDate, the session will no longer be scheduled to run. Once invalidate is called on a session, it can no longer run.
Sourcepub unsafe fn notifyUserWithHaptic_repeatHandler(
&self,
type: WKHapticType,
repeat_handler: Option<&DynBlock<dyn Fn(NonNull<WKHapticType>) -> NSTimeInterval>>,
)
Available on crate features WKInterfaceDevice and block2 only.
pub unsafe fn notifyUserWithHaptic_repeatHandler( &self, type: WKHapticType, repeat_handler: Option<&DynBlock<dyn Fn(NonNull<WKHapticType>) -> NSTimeInterval>>, )
WKInterfaceDevice and block2 only.Parameter type: Haptic type to play
Parameter repeatHandler: an optional block that returns a valid time interval for when to play the next haptic. This value must be > 0.0 and
<
= 60.0. This block also optionally allows the app to change the haptic type that is played by modifying outHapticType. If repeatHandler is NULL, a system default value is used for the repeat interval.
Use this method to start playing a repeating haptic to alert the user. If the app is not active, this will result in a system alert UI. The haptic will repeat at the interval specified by the block in the repeatHandler parameter or at a default interval if repeatHandler is not specified. The haptic will continue playing until one of the following happens:
- the user taps the stop button in the system alarm alert, ending the session
- the session is invalidated by the app while the app is in an active UI state
This method can only be called on a WKExtendedRuntimeSession that was scheduled with startAtDate: and currently has a state of WKExtendedRuntimeSessionStateRunning. If it is called outside that time, it will be ignored.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for WKExtendedRuntimeSession
impl AsRef<AnyObject> for WKExtendedRuntimeSession
Sourceimpl AsRef<NSObject> for WKExtendedRuntimeSession
impl AsRef<NSObject> for WKExtendedRuntimeSession
Sourceimpl Borrow<AnyObject> for WKExtendedRuntimeSession
impl Borrow<AnyObject> for WKExtendedRuntimeSession
Sourceimpl Borrow<NSObject> for WKExtendedRuntimeSession
impl Borrow<NSObject> for WKExtendedRuntimeSession
Sourceimpl ClassType for WKExtendedRuntimeSession
impl ClassType for WKExtendedRuntimeSession
Sourceconst NAME: &'static str = "WKExtendedRuntimeSession"
const NAME: &'static str = "WKExtendedRuntimeSession"
Sourcetype ThreadKind = <<WKExtendedRuntimeSession as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<WKExtendedRuntimeSession as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for WKExtendedRuntimeSession
impl Debug for WKExtendedRuntimeSession
Sourceimpl Deref for WKExtendedRuntimeSession
impl Deref for WKExtendedRuntimeSession
Sourceimpl Hash for WKExtendedRuntimeSession
impl Hash for WKExtendedRuntimeSession
Sourceimpl Message for WKExtendedRuntimeSession
impl Message for WKExtendedRuntimeSession
Sourceimpl NSObjectProtocol for WKExtendedRuntimeSession
impl NSObjectProtocol for WKExtendedRuntimeSession
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref