#[repr(transparent)]pub struct WKExtendedRuntimeSessionInvalidationReason(pub NSInteger);Available on crate feature
WKExtendedRuntimeSession only.Expand description
Defines the reasons for which a session may become invalid.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl WKExtendedRuntimeSessionInvalidationReason
impl WKExtendedRuntimeSessionInvalidationReason
Sourcepub const SessionInProgress: Self
pub const SessionInProgress: Self
A session for this application has already been started, and is currently running, another session can not be started.
Sourcepub const ResignedFrontmost: Self
pub const ResignedFrontmost: Self
The application has lost frontmost status, so the session ended. Examples of actions by the user which cause the session to lose frontmost status include: User pressing digital crown, tapping on a notification to go to another application, switching applications through the dock, or any other apps entering the foreground.
Sourcepub const SuppressedBySystem: Self
pub const SuppressedBySystem: Self
Apple Watch is in a state that doesn’t currently allow this session type to run.