pub struct WKInterfaceSCNScene { /* private fields */ }WKInterfaceObject and WKInterfaceSCNScene only.Expand description
Implementations
Sourceimpl WKInterfaceSCNScene
impl WKInterfaceSCNScene
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn scene(&self) -> Option<Retained<SCNScene>>
Available on crate feature objc2-scene-kit only.
pub unsafe fn scene(&self) -> Option<Retained<SCNScene>>
objc2-scene-kit only.Specifies the scene of the receiver
Sourcepub unsafe fn setScene(&self, scene: Option<&SCNScene>)
Available on crate feature objc2-scene-kit only.
pub unsafe fn setScene(&self, scene: Option<&SCNScene>)
objc2-scene-kit only.Setter for scene.
Sourcepub unsafe fn snapshot(&self) -> Retained<UIImage>
Available on crate feature objc2-ui-kit only.
pub unsafe fn snapshot(&self) -> Retained<UIImage>
objc2-ui-kit only.Draws the contents of the view and returns them as a new image object
This method is thread-safe and may be called at any time.
Sourcepub unsafe fn preferredFramesPerSecond(&self) -> NSInteger
pub unsafe fn preferredFramesPerSecond(&self) -> NSInteger
The rate you want the view to redraw its contents.
When your application sets its preferred frame rate, the view chooses a frame rate as close to that as possible based on the capabilities of the screen the view is displayed on. The actual frame rate chosen is usually a factor of the maximum refresh rate of the screen to provide a consistent frame rate. For example, if the maximum refresh rate of the screen is 60 frames per second, that is also the highest frame rate the view sets as the actual frame rate. However, if you ask for a lower frame rate, it might choose 30, 20, 15 or some other factor to be the actual frame rate. Your application should choose a frame rate that it can consistently maintain. The default value is 0 which means the display link will fire at the native cadence of the display hardware.
Sourcepub unsafe fn setPreferredFramesPerSecond(
&self,
preferred_frames_per_second: NSInteger,
)
pub unsafe fn setPreferredFramesPerSecond( &self, preferred_frames_per_second: NSInteger, )
Setter for preferredFramesPerSecond.
Sourcepub unsafe fn antialiasingMode(&self) -> SCNAntialiasingMode
Available on crate feature objc2-scene-kit only.
pub unsafe fn antialiasingMode(&self) -> SCNAntialiasingMode
objc2-scene-kit only.Defaults to SCNAntialiasingModeNone.
Sourcepub unsafe fn setAntialiasingMode(&self, antialiasing_mode: SCNAntialiasingMode)
Available on crate feature objc2-scene-kit only.
pub unsafe fn setAntialiasingMode(&self, antialiasing_mode: SCNAntialiasingMode)
objc2-scene-kit only.Setter for antialiasingMode.
Methods from Deref<Target = WKInterfaceObject>
pub unsafe fn setHidden(&self, hidden: bool)
pub unsafe fn setAlpha(&self, alpha: CGFloat)
objc2-core-foundation only.pub unsafe fn setSemanticContentAttribute( &self, semantic_content_attribute: WKInterfaceSemanticContentAttribute, )
WKInterfaceDevice only.pub unsafe fn setHorizontalAlignment( &self, horizontal_alignment: WKInterfaceObjectHorizontalAlignment, )
pub unsafe fn setVerticalAlignment( &self, vertical_alignment: WKInterfaceObjectVerticalAlignment, )
pub unsafe fn setWidth(&self, width: CGFloat)
objc2-core-foundation only.pub unsafe fn setHeight(&self, height: CGFloat)
objc2-core-foundation only.pub unsafe fn setRelativeWidth_withAdjustment( &self, width: CGFloat, adjustment: CGFloat, )
objc2-core-foundation only.pub unsafe fn setRelativeHeight_withAdjustment( &self, height: CGFloat, adjustment: CGFloat, )
objc2-core-foundation only.pub unsafe fn sizeToFitWidth(&self)
pub unsafe fn sizeToFitHeight(&self)
pub unsafe fn interfaceProperty(&self) -> Retained<NSString>
pub unsafe fn setAccessibilityIdentifier( &self, accessibility_identifier: Option<&NSString>, )
pub unsafe fn setAccessibilityLabel( &self, accessibility_label: Option<&NSString>, )
pub unsafe fn setAccessibilityHint(&self, accessibility_hint: Option<&NSString>)
pub unsafe fn setAccessibilityValue( &self, accessibility_value: Option<&NSString>, )
pub unsafe fn setIsAccessibilityElement(&self, is_accessibility_element: bool)
pub unsafe fn setAccessibilityTraits( &self, accessibility_traits: UIAccessibilityTraits, )
objc2-ui-kit only.pub unsafe fn setAccessibilityImageRegions( &self, accessibility_image_regions: &NSArray<WKAccessibilityImageRegion>, )
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for WKInterfaceSCNScene
impl AsRef<AnyObject> for WKInterfaceSCNScene
Sourceimpl AsRef<NSObject> for WKInterfaceSCNScene
impl AsRef<NSObject> for WKInterfaceSCNScene
Sourceimpl AsRef<WKInterfaceObject> for WKInterfaceSCNScene
impl AsRef<WKInterfaceObject> for WKInterfaceSCNScene
Sourcefn as_ref(&self) -> &WKInterfaceObject
fn as_ref(&self) -> &WKInterfaceObject
Sourceimpl Borrow<AnyObject> for WKInterfaceSCNScene
impl Borrow<AnyObject> for WKInterfaceSCNScene
Sourceimpl Borrow<NSObject> for WKInterfaceSCNScene
impl Borrow<NSObject> for WKInterfaceSCNScene
Sourceimpl Borrow<WKInterfaceObject> for WKInterfaceSCNScene
impl Borrow<WKInterfaceObject> for WKInterfaceSCNScene
Sourcefn borrow(&self) -> &WKInterfaceObject
fn borrow(&self) -> &WKInterfaceObject
Sourceimpl ClassType for WKInterfaceSCNScene
impl ClassType for WKInterfaceSCNScene
Sourceconst NAME: &'static str = "WKInterfaceSCNScene"
const NAME: &'static str = "WKInterfaceSCNScene"
Sourcetype Super = WKInterfaceObject
type Super = WKInterfaceObject
Sourcetype ThreadKind = <<WKInterfaceSCNScene as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<WKInterfaceSCNScene as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for WKInterfaceSCNScene
impl Debug for WKInterfaceSCNScene
Sourceimpl Deref for WKInterfaceSCNScene
impl Deref for WKInterfaceSCNScene
Sourceimpl Hash for WKInterfaceSCNScene
impl Hash for WKInterfaceSCNScene
Sourceimpl Message for WKInterfaceSCNScene
impl Message for WKInterfaceSCNScene
Sourceimpl NSObjectProtocol for WKInterfaceSCNScene
impl NSObjectProtocol for WKInterfaceSCNScene
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl PartialEq for WKInterfaceSCNScene
impl PartialEq for WKInterfaceSCNScene
Sourceimpl RefEncode for WKInterfaceSCNScene
impl RefEncode for WKInterfaceSCNScene
Sourceconst ENCODING_REF: Encoding = <WKInterfaceObject as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <WKInterfaceObject as ::objc2::RefEncode>::ENCODING_REF
Sourceimpl SCNSceneRenderer for WKInterfaceSCNScene
impl SCNSceneRenderer for WKInterfaceSCNScene
Sourceunsafe fn sceneTime(&self) -> f64
unsafe fn sceneTime(&self) -> f64
Sourceunsafe fn setSceneTime(&self, scene_time: f64)
unsafe fn setSceneTime(&self, scene_time: f64)
sceneTime.Sourceunsafe fn delegate(
&self,
) -> Option<Retained<ProtocolObject<dyn SCNSceneRendererDelegate>>>
unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn SCNSceneRendererDelegate>>>
Sourceunsafe fn setDelegate(
&self,
delegate: Option<&ProtocolObject<dyn SCNSceneRendererDelegate>>,
)
unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn SCNSceneRendererDelegate>>, )
Sourceunsafe fn loops(&self) -> bool
unsafe fn loops(&self) -> bool
Sourceunsafe fn autoenablesDefaultLighting(&self) -> bool
unsafe fn autoenablesDefaultLighting(&self) -> bool
Sourceunsafe fn setAutoenablesDefaultLighting(
&self,
autoenables_default_lighting: bool,
)
unsafe fn setAutoenablesDefaultLighting( &self, autoenables_default_lighting: bool, )
autoenablesDefaultLighting.Sourceunsafe fn isJitteringEnabled(&self) -> bool
unsafe fn isJitteringEnabled(&self) -> bool
Sourceunsafe fn setJitteringEnabled(&self, jittering_enabled: bool)
unsafe fn setJitteringEnabled(&self, jittering_enabled: bool)
isJitteringEnabled.Sourceunsafe fn isTemporalAntialiasingEnabled(&self) -> bool
unsafe fn isTemporalAntialiasingEnabled(&self) -> bool
Sourceunsafe fn setTemporalAntialiasingEnabled(
&self,
temporal_antialiasing_enabled: bool,
)
unsafe fn setTemporalAntialiasingEnabled( &self, temporal_antialiasing_enabled: bool, )
isTemporalAntialiasingEnabled.Sourceunsafe fn showsStatistics(&self) -> bool
unsafe fn showsStatistics(&self) -> bool
Sourceunsafe fn setShowsStatistics(&self, shows_statistics: bool)
unsafe fn setShowsStatistics(&self, shows_statistics: bool)
showsStatistics.Sourceunsafe fn debugOptions(&self) -> SCNDebugOptions
unsafe fn debugOptions(&self) -> SCNDebugOptions
Sourceunsafe fn setDebugOptions(&self, debug_options: SCNDebugOptions)
unsafe fn setDebugOptions(&self, debug_options: SCNDebugOptions)
debugOptions.Sourceunsafe fn renderingAPI(&self) -> SCNRenderingAPI
unsafe fn renderingAPI(&self) -> SCNRenderingAPI
Sourceunsafe fn context(&self) -> *mut c_void
unsafe fn context(&self) -> *mut c_void
Sourceunsafe fn currentTime(&self) -> f64
unsafe fn currentTime(&self) -> f64
Sourceunsafe fn usesReverseZ(&self) -> bool
unsafe fn usesReverseZ(&self) -> bool
Sourceunsafe fn setUsesReverseZ(&self, uses_reverse_z: bool)
unsafe fn setUsesReverseZ(&self, uses_reverse_z: bool)
usesReverseZ.